function M=NSPLINE(x,f)
% M=NSPLINE(x,f)
%
% Interpolation mittels kubischer Splines und natürlichen Randbedingungen bei
% vorgegebenen Stützstellen-Vektor x, Funktionswerte-Vektor f gleicher Länge. 
%
% Das Programm liefert die Momente M(1),...,M(n), welche die Werte der zweiten
% Ableitung des Splines an den Stellen x(1),...,x(n) beschreiben
%
% -----------------------------------------------------------------------------
%
% Eingabe
% -------
% x         Stützstellenvektor
% f         zugehörige Funktionswerte
%
% -----------------------------------------------------------------------------
% 
% Ausgabe
% -------
% M        Vektor der Momente

